#Example of Map Algebra in ArcGIS Pro using Python
# https://pro.arcgis.com/en/pro-app/latest/arcpy/spatial-analyst/an-overview-of-the-map-algebra-operators.htm

#%% Import arcpy & pathlib
import arcpy
from pathlib import Path

#%% Get the input raster
input_raster = Path.cwd().parent / "data" / "raw" / "DEM30.img"
# Check if the input raster exists
if arcpy.Exists(input_raster):
    print("Input raster found")
else:
    print("Input raster not found")

#%% Set the output raster
# Set the path to the the processed folder 
processed_folder = Path.cwd().parent / "data" / "processed"
# Create the processed folder if it does not exist
processed_folder.mkdir(exist_ok=True)
# Set the output raster name (as string), in the processed folder
output_raster = str(processed_folder / "output.img")

#%% Convert the input raster to a raster object
raster = arcpy.Raster(str(input_raster))

#%% Perform map algebra
output_1 = raster * 2
output_2 = output_1 < 200

# %% Save the output raster
output_2.save(output_raster)

# %%
